satsim.pipeline package — SatSim 0.13.0 documentation

# satsim.pipeline package

satsim.pipeline.constant(x, t, ssp=None, value=0.0)

satsim.pipeline.cos(x, t, ssp=None, freq=1, mag_scale=1)

satsim.pipeline.glint(x, t, ssp=None, period=0.0, magnitude=0)

satsim.pipeline.poly(x, t=None, ssp=None, coef=[])

satsim.pipeline.polyt(x, t, ssp=None, coef=[])

satsim.pipeline.sin(x, t, ssp=None, freq=1, mag_scale=1)

satsim.pipeline.sin_add(x, t, ssp=None, freq=1, mag_scale=1)